@@ -19,16 +19,13 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 #  USA
 
-import pygtk
-pygtk.require('2.0')
-import gtk
+from gi.repository import Gtk, Gdk
 
 from ReleaseNotesViewer import ReleaseNotesViewer
-from Core.utils import *
+from Core.utils import error, inhibit_sleep, allow_sleep
 from Core.DistUpgradeFetcherCore import DistUpgradeFetcherCore
 from gettext import gettext as _
 import urllib2
-import dbus
 import os
 import socket
 
@@ -58,17 +55,43 @@ class DistUpgradeFetcherGtk(DistUpgradeFetcherCore):
         allow_sleep()
 
     def showReleaseNotes(self):
+      # first try showing the webkit version, this may fail (return None
+      # because e.g. there is no webkit installed)
+      res = self._try_show_release_notes_webkit()
+      if res is not None:
+          return res
+      else:
+          # fallback to text
+          return self._try_show_release_notes_textview()
+
+    def _try_show_release_notes_webkit(self):
+      if self.new_dist.releaseNotesHtmlUri is not None:
+          try:
+              from ReleaseNotesViewerWebkit import ReleaseNotesViewerWebkit
+              webkit_release_notes = ReleaseNotesViewerWebkit(self.new_dist.releaseNotesHtmlUri)
+              webkit_release_notes.show()
+              self.parent.scrolled_notes.add(webkit_release_notes)
+              res = self.parent.dialog_release_notes.run()
+              self.parent.dialog_release_notes.hide()
+              if res == Gtk.ResponseType.OK:
+                  return True
+              return False
+          except ImportError:
+              pass
+      return None
+
+    def _try_show_release_notes_textview(self):
       # FIXME: care about i18n! (append -$lang or something)
       if self.new_dist.releaseNotesURI != None:
           uri = self._expandUri(self.new_dist.releaseNotesURI)
           self.window_main.set_sensitive(False)
-          self.window_main.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.WATCH))
-          while gtk.events_pending():
-              gtk.main_iteration()
+          self.window_main.get_window().set_cursor(Gdk.Cursor.new(Gdk.CursorType.WATCH))
+          while Gtk.events_pending():
+              Gtk.main_iteration()
 
           # download/display the release notes
           # FIXME: add some progress reporting here
-          res = gtk.RESPONSE_CANCEL
+          res = Gtk.ResponseType.CANCEL
           timeout = socket.getdefaulttimeout()
           try:
               socket.setdefaulttimeout(5)
@@ -84,8 +107,8 @@ class DistUpgradeFetcherGtk(DistUpgradeFetcherCore):
               primary = "<span weight=\"bold\" size=\"larger\">%s</span>" % \
                         _("Could not find the release notes")
               secondary = _("The server may be overloaded. ")
-              dialog = gtk.MessageDialog(self.window_main,gtk.DIALOG_MODAL,
-                                         gtk.MESSAGE_ERROR,gtk.BUTTONS_CLOSE,"")
+              dialog = Gtk.MessageDialog(self.window_main,Gtk.DialogFlags.MODAL,
+                                         Gtk.MessageType.ERROR,Gtk.ButtonsType.CLOSE,"")
               dialog.set_title("")
               dialog.set_markup(primary);
               dialog.format_secondary_text(secondary);
@@ -95,8 +118,8 @@ class DistUpgradeFetcherGtk(DistUpgradeFetcherCore):
               primary = "<span weight=\"bold\" size=\"larger\">%s</span>" % \
                         _("Could not download the release notes")
               secondary = _("Please check your internet connection.")
-              dialog = gtk.MessageDialog(self.window_main,gtk.DIALOG_MODAL,
-                                         gtk.MESSAGE_ERROR,gtk.BUTTONS_CLOSE,"")
+              dialog = Gtk.MessageDialog(self.window_main,Gtk.DialogFlags.MODAL,
+                                         Gtk.MessageType.ERROR,Gtk.ButtonsType.CLOSE,"")
               dialog.set_title("")
               dialog.set_markup(primary);
               dialog.format_secondary_text(secondary);
@@ -104,9 +127,9 @@ class DistUpgradeFetcherGtk(DistUpgradeFetcherCore):
               dialog.destroy()
           socket.setdefaulttimeout(timeout)              
           self.window_main.set_sensitive(True)
-          self.window_main.window.set_cursor(None)
+          self.window_main.get_window().set_cursor(None)
           # user clicked cancel
-          if res == gtk.RESPONSE_OK:
+          if res == Gtk.ResponseType.OK:
               return True
       return False
 
