@@ -23,7 +23,6 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 #  USA
 
-from gi.repository import GLib
 from gi.repository import Gio
 from gi.repository import GObject
 from gi.repository import Gtk
@@ -64,7 +63,7 @@ class CheckNewReleaseGtk(SimpleGtkbuilderApp):
   def __init__(self, options):
     SimpleGtkbuilderApp.__init__(self, options.datadir+"/gtkbuilder/UpgradePromptDialog.ui", "update-manager")
     self.new_dist = None
-    logging.debug("runnign with devel=%s proposed=%s" % (
+    logging.debug("running with devel=%s proposed=%s" % (
             options.devel_release, options.proposed_release))
     m = MetaRelease(useDevelopmentRelease=options.devel_release,
                     useProposed=options.proposed_release)
@@ -118,6 +117,7 @@ class CheckNewReleaseGtk(SimpleGtkbuilderApp):
                                  parent=self,
                                  progress=progress)
     res = fetcher.run()
+    res # pyflakes
 
   def on_button_ask_me_later_clicked(self, button):
     logging.debug("ask me later")
@@ -159,12 +159,12 @@ class CheckNewReleaseGtk(SimpleGtkbuilderApp):
       Gtk.main_quit()
 
 if __name__ == "__main__":
-  APP="update-manager"
-  DIR="/usr/share/locale"
 
   Gtk.init_check(sys.argv)
 
-  gettext.install(APP, DIR, unicode=True)
+  gettext.bindtextdomain("update-manager", "/usr/share/locale")
+  gettext.textdomain("update-manager")
+
   try:
     locale.setlocale(locale.LC_ALL, "")
   except:
@@ -173,19 +173,23 @@ if __name__ == "__main__":
   init_proxy()
 
   parser = OptionParser()
+  #FIXME: Workaround a bug in optparser which doesn't handle unicode/str
+  #       correctly, see http://bugs.python.org/issue4391
+  #       Shoudl be resolved by Python3
+  enc = locale.getpreferredencoding()
   parser.add_option ("-d", "--devel-release", action="store_true",
                      dest="devel_release", default=False,
                      help=_("Check if upgrading to the latest devel release "
-                          "is possible"))
+                          "is possible").decode(enc))
   parser.add_option ("-p", "--proposed", action="store_true",
                      dest="proposed_release", default=False,
                      help=_("Try upgrading to the latest release using "
-                            "the upgrader from $distro-proposed"))
+                            "the upgrader from $distro-proposed").decode(enc))
   # mostly useful for development
   parser.add_option ("", "--datadir", default="/usr/share/update-manager")
   parser.add_option ("", "--test-uri")
   parser.add_option ("", "--debug", action="store_true", default=False,
-                     help="Add debug output")
+                     help=_("Add debug output").decode(enc))
   (options, args) = parser.parse_args()
 
   if options.debug:
